@@ -1,5 +1,5 @@
 from db_hj3415 import mongo2
-from db_path import MONGO_ADDR
+from scraper_hj3415.db_path import MONGO_ADDR
 
 import logging
 logger = logging.getLogger(__name__)
